@@ -18,12 +18,13 @@ from ..responses import (
 )
 from ..utils import flatten
 from .executable import Compiled, Executable
+from .whereable import Whereable
 
 Format = Literal["BOUNDS", "COUNT", "HASHES", "IDS", "OBJECTS", "POINTS"]
-Output = Union[Sequence[Union[Format, int]]]
+Output = Sequence[Union[Format, int]]
 
 
-class Nearby(Executable):
+class Nearby(Executable, Whereable):
     """Nearby searches a key for objects that are close by."""
 
     _key: str
@@ -36,7 +37,6 @@ class Nearby(Executable):
     _fence: bool = False
     _detect: Optional[List[FenceDetect]] = []
     _commands: Optional[List[FenceCommand]] = []
-    _where: List[List[Union[str, int]]] = []
 
     def __init__(self, client: Client, key: str, hook=None) -> None:
         """__init__.
@@ -116,8 +116,8 @@ class Nearby(Executable):
         """Option to filter what commands should be triggering a geo fence event.
 
         Args:
-            which (Optional[List[FenceCommand]]): which commands trigger a geo fence event
-                defaults to 'SET,DEL,JSET,JDEL' if not set
+            which (Optional[List[FenceCommand]]): which commands trigger a geo fence
+            event defaults to 'SET,DEL,JSET,JDEL' if not set
 
         Returns:
             Nearby
@@ -156,7 +156,8 @@ class Nearby(Executable):
         return self
 
     def match(self, value: str) -> Nearby:
-        """Match can be used to filtered objects considered in the search with a glob pattern.
+        """Match can be used to filtered objects considered in the search with a
+        glob pattern.
 
         Args:
             value (str): value
@@ -168,25 +169,9 @@ class Nearby(Executable):
 
         return self
 
-    def where(self, field: str, min: int, max: int) -> Nearby:
-        """Filter the search by field
-
-        Args:
-            field (str): field name
-            min (int): minimum value of field
-            max (int): maximum value of field
-
-        Returns:
-            Within
-        """
-
-        self._where.append([SubCommand.WHERE, field, min, max])
-
-        return self
-
     def sparse(self, value: int) -> Nearby:
-        """Instead of returning all results of a search. Return a sparse result evenly distributed
-        in the given search area. EXPERIMENTAL
+        """Instead of returning all results of a search. Return a sparse result evenly
+        distributed in the given search area. EXPERIMENTAL
 
         Args:
             value (int): values between 1 and 8
@@ -325,24 +310,6 @@ class Nearby(Executable):
 
         return PointsResponse(**(await self.exec()))
 
-    def __compile_where(self) -> CommandArgs:
-        """__compile_where.
-
-        Args:
-
-        Returns:
-            CommandArgs
-
-        """
-        w = []
-
-        if len(self._where) > 0:
-            for i in self._where:
-                w.extend(i)
-            return w
-        else:
-            return []
-
     def __compile_options(self) -> CommandArgs:
         """__compile_options.
 
@@ -404,7 +371,7 @@ class Nearby(Executable):
             [
                 self._key,
                 *(self.__compile_options()),
-                *(self.__compile_where()),
+                *(self.compile_where()),
                 *(self.__compile_fence()),
                 *(self._output if self._output else []),
                 *(self._query.get()),
